 !
 !  NAME:
 !  	test_uv.f
 !
 !  PURPOSE:
 !	Test the spica_read_1a_mod module for UV data
 ! 	After compilation, use the following command:
 !	 ./test_uv 1AUV_full_path
 !
 ! Author:
 !   Nicolas Chapron
 !     CNRS | LATMOS - Laboratoire Atmospheres, Milieux, Observations Spatiales.
 !     11 boulevard d'Alembert
 !     78280 Guyancourt
 !     France
 !     Tel. 33-(0) 1 80 28 50 57
 !     Email. nicolas.chapron@latmos.ipsl.fr
 !
 !  SVN Revision:
 !      $Rev: 2347 $
 !      $Author: chapron $
 !      $Date: 2014-10-28 16:05:49 +0100 (Mar, 28 oct 2014) $
 !

program test

    ! Definitions and declarations
    use spica_read_1a_mod
    integer i
    type(struc_1AFile) :: File1A
    character(len=2048) filename

    ! File to read:
    call get_command_argument(1,filename)
    
    ! Read the 1A level, create the structture
    File1A = spica_read_1A(filename,1,0)

    !! Print some data
    print *, 'Observation parameters:'
    print *,File1A%Parameters%codeop
    print *,File1A%Parameters%binning
    print *,File1A%Parameters%ti
    print *,File1A%Parameters%ht
    print *,File1A%Parameters%x0
    print *,File1A%Parameters%y0
    print *,File1A%Parameters%slit
    print *,File1A%Parameters%peltier
    print *,File1A%Parameters%uvsampling
    print *,File1A%Parameters%iron
    print *,File1A%Parameters%soiron

    print *, '===== Observation information ====='
    print *,File1A%Info%DCProc
    print *,File1A%Info%ENProc
    print *,File1A%Info%SATProc
    print *,File1A%Info%COSProc
    print *,File1A%Info%Data_status
    print *,File1A%Info%Geo_status
	print *,File1A%Info%Flag_status
	print *,File1A%Info%DC_status

    print *, '===== Temperatures sample ====='
    do, i=100,200
        print *, File1A%Parameters%t_structure(i)
    enddo

    print *, '===== Geometry information ====='
    print *,File1A%GeoInfo%target
    print *,File1A%GeoInfo%shadowcone
    print *,File1A%GeoInfo%slitcenter(1)
    print *,File1A%GeoInfo%slitcenter(2)
    print *,File1A%GeoInfo%sunlat
    print *,File1A%GeoInfo%sunlong
    print *,File1A%GeoInfo%sundist
    print *,File1A%GeoInfo%sunls
    print *,File1A%GeoInfo%sunra
    print *,File1A%GeoInfo%sundec

    print *, '===== Geometry records sample ====='
    print *,File1A%Geo%Record%time(1)
    print *,File1A%Geo%Record%number(1)

    print *, '===== Geometry of the spacecraft ====='
    print *,File1A%Geo%Spacecraft%lat(100)
    print *,File1A%Geo%Spacecraft%long(100)
    print *,File1A%Geo%Spacecraft%alt(100)
    print *,File1A%Geo%Spacecraft%sza(100)
    print *,File1A%Geo%Spacecraft%shadowconeratio(100)

    print *, '===== Data sample ====='
    print *,File1A%CleanData(101,100:200,1)

    print *, '===== Flag sample ====='
    print *,File1A%Flag(101,916:960,5)

    print *, '===== Error on correction sample ====='
    print *,File1A%ErrData(101,100:200,1)

end program test
